<?php

/**
 *
 * $Id: class.StateHolder.php,v 1.6 2005/05/16 21:13:06 dgorski Exp $
 *
 * This file is part of coWiki. coWiki is free software under the terms of
 * the GNU General Public License (GPL). Read the LICENSE file. If you did
 * not receive a copy of the license and are not able to obtain it through
 * the internet, please send a note to <license@cowiki.org> so we can mail
 * you a copy immediately.
 *
 * @package     htdocs
 * @subpackage  setup
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @copyright   (C) Daniel T. Gorski, {@link http://www.develnet.org}
 * @license     http://www.gnu.org/licenses/gpl.html
 * @version     $Revision: 1.6 $
 *
 */

/**
 * State holder for installer tasks
 *
 * @package     htdocs
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @since       coWiki 0.4.0
 */
class StateHolder {

    static public function getInstance() {
        static $Inst = null;
        if (!$Inst) { $sClassName = __CLASS__; $Inst = new $sClassName; }
        return $Inst;
    }

    // --------------------------------------------------------------------

    private function __construct() {
        ini_set('arg_separator.output', '&amp;');
        ini_set('session.use_trans_sid', 0);
        session_name('sid');
        session_start();

        // Determine if we are running via the CGI interface
        $this->setIsCGI(strpos(strtolower(PHP_SAPI), 'cgi') !== false);

        // Determine if we are running on Windows32
        $this->setIsWindows(strpos(strtolower(PHP_OS), 'win') !== false);

        // ----------------------------------------------------------------

        // If include paths has not been loaded yet - load them once
        if (!$this->hasPathsLoaded()) {

            $sPath = @file_get_contents(SETUP_PATH.'/../include.path');

            // The original delimiter is ':', if the 'include.path' file
            // has not been changed yet, but can be ';' after a change.
            // E.g. on Win32 the content of 'include.path' might look like
            // '.;C:\some\path\'.
            $sDeli = (substr_count($sPath, ';') && $this->isWindows())
                        ? ';'
                        : ':';

            $aPath = explode($sDeli, $sPath);
            $sHtdocs   = trim(@$aPath[0]);
            $sIncludes = trim(@$aPath[1]);
            $sMisc     = trim(@$aPath[2]);


            // If path is not absolute, go up in hierarchy as these very
            // scripts are located below the main scripts
            if (substr($sHtdocs, 0, 1) == '.') {
                $sHtdocs = realpath(SETUP_PATH.'/../'.$sHtdocs);
            } else {
                $sHtdocs = realpath($sHtdocs);
            }

            if (substr($sIncludes, 0, 1) == '.') {
                $sIncludes = realpath(SETUP_PATH.'/../'.$sIncludes);
            } else {
                $sIncludes = realpath($sIncludes);
            }

            if (substr($sMisc, 0, 1) == '.') {
                $sMisc = realpath(SETUP_PATH.'/../'.$sMisc);
            } else {
                $sMisc = realpath($sMisc);
            }

            $this->setHtdocsPath($sHtdocs);
            $this->setIncludesPath($sIncludes);
            $this->setMiscPath($sMisc);

            $this->setHasPathsLoaded(true);
        }

        // ----------------------------------------------------------------

        // Depending on the existance of the controller files
        // '../install.pending' and '../install.seal', different states
        // of the software setup are indicated.
        //
        // E.g. If both files exist, an update over an existing
        // installation (update) is indicated.

        $bPending = file_exists(SETUP_PATH.'/../install.pending');
        $bSeal    = file_exists(SETUP_PATH.'/../install.seal');;

        // 'pending' exists, 'seal' does not -> initial setup
        if ($bPending && !$bSeal) {
            $this->setIsInitialSetup(true);
            return; // leave constructor
        }

        // 'pending' does not exist, 'seal' does -> initial setup finished
        if (!$bPending && $bSeal) {
            $this->setIsInitialSetup(false);
            return; // leave constructor
        }

        // 'pending' exists, 'seal' does too -> it's an update
        if ($bPending && $bSeal) {
            $this->setIsUpdateSetup(true);
            return; // leave constructor
        }

        // 'pending' doesn't exists, 'seal' neigher -> bad! Invoke an
        // initial setup as something went obviously wrong.
        if (!$bPending && !$bSeal) {
            $this->setIsInitialSetup(true);
            return; // leave constructor
        }
    }

    // --------------------------------------------------------------------

    // Assemble DSN path
    public function assembleDSN($sScheme, $sUser, $sPass, $sHost,
                                $sPort, $sDatabase) {
        
        $sStr = $sScheme . '://' . $sUser . ':' . $sPass;
        $sStr .= '@' . $sHost;
        if (trim($sPort) != '') { $sStr .= ':' . $sPort; }
        $sStr .=  '/' . $sDatabase;

        return $sStr;
    }

    // --------------------------------------------------------------------

    public function getDocumentStorageDSN() {
        return $this->assembleDSN(
            $this->getDocStorageScheme(),
            $this->getDocStorageConnectorUser(),
            $this->getDocStorageConnectorPassword(),
            $this->getDocHost(),
            $this->getDocHostPort(),
            $this->getDocDatabaseName()
        );
    }

    // --------------------------------------------------------------------

    public function getDocumentStorageRootDSN() {
        return $this->assembleDSN(
            $this->getDocStorageScheme(),
            $this->getDocStorageAdminUser(),
            $this->getDocStorageAdminPassword(),
            $this->getDocHost(),
            $this->getDocHostPort(),
            $this->getDocDatabaseName()
        );
    }

    // --------------------------------------------------------------------

    public function setReturnReferenceScript($sStr) {
        $sStr = preg_replace('#[^a-z0-9._]$i#', '', trim($sStr));
        $this->setKeyValue('returnScript', trim($sStr));
    }
    public function getReturnReferenceScript() {
        return $this->getKeyValue('returnScript');
    }

    // --------------------------------------------------------------------

    public function setKeyValue($sKey, $mVal) {
        $this->setKeyValueNamespace('setup', $sKey, $mVal);
    }
    public function getKeyValue($sKey) {
        return $this->getKeyValueNamespace('setup', $sKey);
    }

    public function setKeyValueNamespace($sNs, $sKey, $mValue) {
        $_SESSION[$sNs][$sKey] = $mValue;
    }

    public function getKeyValueNamespace($sNs, $sKey) {
        if (isset($_SESSION[$sNs][$sKey])) {
            return $_SESSION[$sNs][$sKey];
        }
        return null;
    }

    // ====================================================================

    public function setIsInitialSetup($bFlag) {
        $this->setKeyValue('initialSetup', (bool)$bFlag);
    }
    public function isInitialSetup() {
        return (bool)$this->getKeyValue('initialSetup');
    }

    public function setIsUpdateSetup($bFlag) {
        $this->setIsInitialSetup(!(bool)$bFlag);
    }
    public function isUpdateSetup() {
        return !$this->isInitialSetup();
    }

    // ====================================================================

    public function setIsValidUser($bFlag) {
        $this->setKeyValue('validUser', (bool)$bFlag);
    }
    public function isValidUser() {
        return (bool)$this->getKeyValue('validUser');
    }

    // --------------------------------------------------------------------

    public function setRootUserPassword($sStr) {
        $this->setKeyValue('applicationRootUserPass', $sStr);
    }
    public function getRootUserPassword() {
        return $this->getKeyValue('applicationRootUserPass');
    }

    // ====================================================================

    private function setIsCGI($bFlag) {
        $this->setKeyValue('isCGI', (bool)$bFlag);
    }
    public function isCGI() {
        return (bool)$this->getKeyValue('isCGI');
    }

    // --------------------------------------------------------------------

    private function setIsWindows($bFlag) {
        $this->setKeyValue('isWindows', (bool)$bFlag);
    }
    public function isWindows() {
        return (bool)$this->getKeyValue('isWindows');
    }

    // ====================================================================

    private function setHasPathsLoaded($bFlag) {
        $this->setKeyValue('hasPathsLoaded', (bool)$bFlag);
    }
    private function hasPathsLoaded() {
        return (bool)$this->getKeyValue('hasPathsLoaded');
    }

    // --------------------------------------------------------------------

    public function setHtdocsPath($sStr) {
        $sStr = preg_replace('#[\\/]+$#', '', trim($sStr));
        $this->setKeyValue('htdocsPath', $sStr);
    }
    public function getHtdocsPath() {
        return $this->getKeyValue('htdocsPath');
    }

    // --------------------------------------------------------------------

    public function setIncludesPath($sStr) {
        $sStr = preg_replace('#[\\/]+$#', '', trim($sStr));
        $this->setKeyValue('includesPath', trim($sStr));
    }
    public function getIncludesPath() {
        return $this->getKeyValue('includesPath');
    }

    // --------------------------------------------------------------------

    public function setMiscPath($sStr) {
        $sStr = preg_replace('#[\\/]+$#', '', trim($sStr));
        $this->setKeyValue('miscPath', trim($sStr));
    }
    public function getMiscPath() {
        return $this->getKeyValue('miscPath');
    }

    // ====================================================================

    public function setCompleteClassLoaderPath($sStr) {
        $this->setKeyValue('classLoaderPath', $sStr);
    }
    public function getCompleteClassLoaderPath() {
        return $this->getKeyValue('classLoaderPath');
    }

    public function hasCompleteClassLoaderPath() {
        return $this->getCompleteClassLoaderPath() !== null;
    }

    // ====================================================================

    public function setDocStorageScheme($sStr) {
        $this->setKeyValue('docStorageScheme', $sStr);
    }
    public function getDocStorageScheme() {
        return $this->getKeyValue('docStorageScheme');
    }

    // --------------------------------------------------------------------

    public function setDocStorageConnectorUser($sStr) {
        $this->setKeyValue('docConnectorUser', $sStr);
    }
    public function getDocStorageConnectorUser() {
        return $this->getKeyValue('docConnectorUser');
    }

    // --------------------------------------------------------------------

    public function setDocStorageConnectorPassword($sStr) {
        $this->setKeyValue('docConnectorPassword', $sStr);
    }
    public function getDocStorageConnectorPassword() {
        return $this->getKeyValue('docConnectorPassword');
    }

    // --------------------------------------------------------------------

    public function setDocHost($sStr) {
        $this->setKeyValue('docHost', $sStr);
    }
    public function getDocHost() {
        return $this->getKeyValue('docHost');
    }

    // --------------------------------------------------------------------

    public function setDocHostPort($sStr) {
        $this->setKeyValue('docHostPort', $sStr);
    }
    public function getDocHostPort() {
        return $this->getKeyValue('docHostPort');
    }

    // --------------------------------------------------------------------

    public function setDocDatabaseName($sStr) {
        $this->setKeyValue('docDatabaseName', $sStr);
    }
    public function getDocDatabaseName() {
        return $this->getKeyValue('docDatabaseName');
    }

    // --------------------------------------------------------------------

    public function setHasDocStorageScheme($bFlag) {
        $this->setKeyValue('hasDocStorageScheme', (bool)$bFlag);
    }
    public function hasDocStorageScheme() {
        return (bool)$this->getKeyValue('hasDocStorageScheme');
    }

    public function setHasDocStorageResources($bFlag) {
        $this->setKeyValue('hasDocStorageResources', (bool)$bFlag);
    }
    public function hasDocStorageResources() {
        return (bool)$this->getKeyValue('hasDocStorageResources');
    }

    // --------------------------------------------------------------------

    public function setShallCreateNewConnectorUser($bFlag) {
        $this->setKeyValue('docDatabaseCreateConnector', (bool)$bFlag);
    }
    public function shallCreateNewConnectorUser() {
        return (bool)$this->getKeyValue('docDatabaseCreateConnector');
    }

    public function setShallCreateNewDocumentDatabase($bFlag) {
        $this->setKeyValue('docDatabaseCreateDB', (bool)$bFlag);
    }
    public function shallCreateNewDocumentDatabase() {
        return (bool)$this->getKeyValue('docDatabaseCreateDB');
    }

    // --------------------------------------------------------------------

    public function setDocStorageAdminUser($sStr) {
        $this->setKeyValue('docAdminUser', $sStr);
    }
    public function getDocStorageAdminUser() {
        return $this->getKeyValue('docAdminUser');
    }

    // --------------------------------------------------------------------

    public function setDocStorageAdminPassword($sStr) {
        $this->setKeyValue('docAdminPassword', $sStr);
    }
    public function getDocStorageAdminPassword() {
        return $this->getKeyValue('docAdminPassword');
    }

    // --------------------------------------------------------------------

    public function setHasValidDocStorageConnection($bFlag) {
        $this->setKeyValue('hasValidDocStorageConnection', (bool)$bFlag);
    }
    public function hasValidDocStorageConnection() {
        return (bool)$this->getKeyValue('hasValidDocStorageConnection');
    }

    // ====================================================================

    public function setHasAboutData($bFlag) {
        $this->setKeyValue('hasAboutData', (bool)$bFlag);
    }
    public function hasAboutData() {
        return (bool)$this->getKeyValue('hasAboutData');
    }

    public function setAboutTitle($sStr) {
        $this->setKeyValue('aboutTitle', $sStr);
    }
    public function getAboutTitle() {
        return $this->getKeyValue('aboutTitle');
    }

    public function setAboutDescription($sStr) {
        $this->setKeyValue('aboutDesc', preg_replace('#[\r|\n]#', ' ', $sStr));
    }
    public function getAboutDescription() {
        return $this->getKeyValue('aboutDesc');
    }

    // ====================================================================

    public function setHasMailData($bFlag) {
        $this->setKeyValue('hasMailData', (bool)$bFlag);
    }
    public function hasMailData() {
        return (bool)$this->getKeyValue('hasMailData');
    }

    public function setMailFullName($sStr) {
        $this->setKeyValue('mailFullName', $sStr);
    }
    public function getMailFullName() {
        return $this->getKeyValue('mailFullName');
    }

    public function setMailReturnPath($sStr) {
        $this->setKeyValue('mailReturnPath', $sStr);
    }
    public function getMailReturnPath() {
        return $this->getKeyValue('mailReturnPath');
    }

    public function setMailAbusePath($sStr) {
        $this->setKeyValue('mailAbusePath', $sStr);
    }
    public function getMailAbusePath() {
        return $this->getKeyValue('mailAbusePath');
    }

    // ====================================================================

    public function setHasVisualSettings($bFlag) {
        $this->setKeyValue('hasVisualSettings', (bool)$bFlag);
    }
    public function hasVisualSettings() {
        return (bool)$this->getKeyValue('hasVisualSettings');
    }

    public function setLanguageLocale($sStr) {
        $this->setKeyValue('visualLanguageLocale', $sStr);
    }
    public function getLanguageLocale() {
        return $this->getKeyValue('visualLanguageLocale');
    }

    public function setTemplateActive($sStr) {
        $this->setKeyValue('visualTemplateActive', $sStr);
    }
    public function getTemplateActive() {
        return $this->getKeyValue('visualTemplateActive');
    }

    public function setHasEmailObfuscation($bFlag) {
        $this->setKeyValue('visualObfuscateEmails', (bool)$bFlag);
    }
    public function hasEmailObfuscation() {
        return (bool)$this->getKeyValue('visualObfuscateEmails');
    }

    public function setShowProcessingTime($bFlag) {
        $this->setKeyValue('visualShowProcessingTime', (bool)$bFlag);
    }
    public function showProcessingTime() {
        return (bool)$this->getKeyValue('visualShowProcessingTime');
    }

    // ====================================================================

    public function setHasDebugLevelValue($bFlag) {
        $this->setKeyValue('hasDebugLevelValue', (bool)$bFlag);
    }
    public function hasDebugLevelValue() {
        return (bool)$this->getKeyValue('hasDebugLevelValue');
    }

    public function setDebugLevelValue($nNum) {
        $this->setKeyValue('debugLevelValue', (int)$nNum);
    }
    public function getDebugLevelValue() {
        return (int)$this->getKeyValue('debugLevelValue');
    }

    public function setDebugLevelString($sStr) {
        $this->setKeyValue('debugLevelString', trim($sStr));
    }
    public function getDebugLevelString() {
        return $this->getKeyValue('debugLevelString');
    }

} // of class

/*
    Last night, ah, yesternight, betwixt her lips and mine
    There fell thy shadow, Cynara! thy breath was shed
    Upon my soul between the kisses and the wine;
    And I was desolate and sick of an old passion,
    Yea, I was desolate and bowed my head:
    I have been faithful to thee, Cynara! in my fashion.

    All night upon mine heart I felt her warm heart beat,
    Night-long within mine arms in love and asleep she lay;
    Surely the kisses of her bought red mouth were sweet;
    But I was desolate and sick of an old passion,
    When I awoke and found the dawn was gray:
    I have been faithful to thee, Cynara! in my fashion.

    I have forgot much, Cynara! gone with the wind,
    Flung roses, roses riotously with the throng,
    Dancing, to put thy pale, lost lilies out of the mind;
    But I was desolate and sick of an old passion,
    Yea, all the time, because the dance was long:
    I have been faithful to thee, Cynara! in my fashion.

    I cried for madder music and for stronger wine,
    But when the feast is finished and the lamps expire,
    Then falls thy shadow, Cynara! the night is thine;
    And I am desolate and sick of an old passion,
    Yea hungry for the lips of my desire:
    I have been faithful to thee, Cynara! in my fashion.
*/

?>