<?php

/**
 *
 * $Id: class.TaskApplicationAboutSettings.php,v 1.2 2005/04/22 23:56:00 dgorski Exp $
 *
 * This file is part of coWiki. coWiki is free software under the terms of
 * the GNU General Public License (GPL). Read the LICENSE file. If you did
 * not receive a copy of the license and are not able to obtain it through
 * the internet, please send a note to <license@cowiki.org> so we can mail
 * you a copy immediately.
 *
 * @package     htdocs
 * @subpackage  setup
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @copyright   (C) Daniel T. Gorski, {@link http://www.develnet.org}
 * @license     http://www.gnu.org/licenses/gpl.html
 * @version     $Revision: 1.2 $
 *
 */

/**
 * coWiki - Installer task class
 *
 * @package     htdocs
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @since       coWiki 0.4.0
 */
class TaskApplicationAboutSettings extends AbstractTask {

    public function __construct($Tpl) {
        parent::__construct($Tpl);
        parent::checkValidUser();
        parent::loadClassLoader();

        // ---

        // Load configuration data only once. Keep it in sesssion (state
        // holder) then
        if (!$this->State->hasAboutData()) {

            // Load application configuration
            $Conf = $this->getConfig();

            // Initialize state holder values
            $this->State->setAboutTitle(
                $Conf->getSectionKeyValue('ABOUT', 'TITLE')
            );
            $this->State->setAboutDescription(
                $Conf->getSectionKeyValue('ABOUT', 'DESCRIPTION')
            );

            $this->State->setHasAboutData(true);
        }
    }

    // --------------------------------------------------------------------

    public function isRequired() {
        return true;
    }

    // --------------------------------------------------------------------

    public function validate() {

        // Store submitted values
        $this->State->setAboutTitle(@$_POST['title']);
        $this->State->setAboutDescription(@$_POST['description']);

        // Insist on 'valid' values. At the time of writing this code,
        // these values *might* be empty, but shouldn't. If a user takes
        // advantage of this installer, he must enter these values.

        if ($this->State->getAboutTitle() == ''
            || $this->State->getAboutDescription() == '') {
            $this->addErr('Please fill out the fields.');
        }

        return !$this->hasMessage();
    }

    // --------------------------------------------------------------------

    public function render() {

        $sStr = 'Informational data about <i>this</i> coWiki, its topic,
                 its theme.
                 Describe here what your coWiki is about, its main title.
                 This consists of a short title (max. about 40 characters)
                 and a longer description.
                 <br/><br/>

                 These entries might look like Title: \'<i>Internal FooBar
                 knowledge base</i>\' and its Description: \'<i>FooBar is
                 the divine documentation project and knowledge base of
                 Turtle Oil Inc. and beyond. Everything you always wanted to
                 know about alien life forms, but were afraid to ask</i>\'.
                 <br/><br/>

                 This information will be e.g. used for generation of RSS
                 feeds that will be provided to public audience and to feed
                 search engines.';

        $sStr .=  '<br/><br/>';

        $sStr .=  '<table align="center" cellspacing="0"
                    cellpadding="0" border="0">';
        $sStr .=    '<tr>';

        $sStr .=      '<td>';
        $sStr .=        '<fieldset>';
        $sStr .=          '<legend>About this coWiki</legend>';

        $sStr .=          '<table cellpadding="2" cellspacing="0"';
        $sStr .=          ' border="0" class="fieldset-content">';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                'Title / Theme:';
        $sStr .=              '</td>';
        $sStr .=              '<td colspan="3">';
        $sStr .=                '<input type="text" name="title"';
        $sStr .=                ' size="40" maxlength="40" value="';
        $sStr .=                  $this->State->getAboutTitle();
        $sStr .=                '">';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=            '<tr valign="top">';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                'Description:';
        $sStr .=              '</td>';
        $sStr .=              '<td colspan="3">';
        $sStr .=                '<textarea name="description" rows="4"';
        $sStr .=                  ' style="width:100%">';
        $sStr .=                  $this->State->getAboutDescription();
        $sStr .=                '</textarea>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=          '</table>';
        $sStr .=        '</fieldset>';
        $sStr .=      '</td>';

        $sStr .=    '</tr>';
        $sStr .=  '</table>';

        $sStr .=  '<br/>';

        // Define content
        $this->Tpl->assign('CONTENT', $sStr);

        // Define informational/warning/error messages
        $this->Tpl->assign('MESSAGE', $this->getMsgQueueFormatted());

        echo $this->Tpl->parse(SETUP_PATH.'/tpl/window.default.tpl');
    }

} // of class

/*
    When you walk right by my side everything just feels alright
    all the stars are shining bright, I feel lucky

    When I'm hanging out with you and you do the things you do
    when you look into my eyes I'm so glad

    But there's something sad 'bout you you're a guy and I'm one, too
    you like girls and I like you so I don't know what to do

    I just hide my face away, standing in the closet
    and pretending I feel fine

    I just hide my tears away, you know I'm a big boy
    you won't see me crying

    When I walk around with you and you do the things you do
    when you look into my eyes, feel like crying

    When you call me on the phone telling me you feel alone
    It's just tearing out my heart feel like dying

    But there's something sad 'bout you you're a guy and I'm one, too
    you like girls and I like you so I don't know what to do

    I just hide my face away, standing in the closet
    and pretending I feel fine

    I just hide my tears away, you know I'm a big boy
    you won't see me crying
*/

?>