<?php

/**
 *
 * $Id: class.TaskApplicationDebugSettings.php,v 1.3 2005/04/29 00:45:06 dgorski Exp $
 *
 * This file is part of coWiki. coWiki is free software under the terms of
 * the GNU General Public License (GPL). Read the LICENSE file. If you did
 * not receive a copy of the license and are not able to obtain it through
 * the internet, please send a note to <license@cowiki.org> so we can mail
 * you a copy immediately.
 *
 * @package     htdocs
 * @subpackage  setup
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @copyright   (C) Daniel T. Gorski, {@link http://www.develnet.org}
 * @license     http://www.gnu.org/licenses/gpl.html
 * @version     $Revision: 1.3 $
 *
 */

/**
 * coWiki - Installer task class
 *
 * @package     htdocs
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @since       coWiki 0.4.0
 */
class TaskApplicationDebugSettings extends AbstractTask {

    // --------------------------------------------------------------------

    public function __construct($Tpl) {
        parent::__construct($Tpl);
        parent::checkValidUser();
        parent::loadClassLoader();

        // ---

        // Trigger loading of the Logger. That loads the Logger and its
        // constants.
        Logger::triggerAutoload();

        // Load configuration data only once. Keep it in sesssion (state
        // holder) then
        if (!$this->State->hasDebugLevelValue()) {

            // Load application configuration
            $Conf = $this->getConfig();

            $sStr = $Conf->getSectionKeyValue('SOFTWARE', 'DEBUG_LEVEL');

            // Empty string -> D_OFF
            if ($sStr == '') { $sStr = 'D_OFF'; }

            // Simple access to internal Logger constants
            $sStr = str_replace('D_', 'Logger::D_', $sStr);

            @eval('$nLevel = '.$sStr.';');

            // Initialize state holder values
            $this->State->setDebugLevelValue($nLevel);

            $this->State->setHasDebugLevelValue(true);
        }
    }

    // --------------------------------------------------------------------

    public function isRequired() {
        return true;
    }

    // --------------------------------------------------------------------

    public function validate() {

        // Generate and store submitted values
        $nLevel = 0;
        $sLevel = '';
        $aConst = Logger::getDebugConstants();

        foreach ($aConst as $k => $v) {
            if (isset($_POST[$k])) {
                $nLevel |= $v;
                $sLevel .= $k . ' | ';
            }
        }

        // Remove trailing chars
        $sLevel = substr($sLevel, 0, -3);

        $this->State->setDebugLevelValue($nLevel);
        $this->State->setDebugLevelString($sLevel);

        return true;
    }

    // --------------------------------------------------------------------

    public function render() {

        $nLevel = $this->State->getDebugLevelValue();

        $sStr = 'coWiki internally logs information to the <tt>error.log</tt>
                file that has been defined for your virtual webserver host.
                No user will see these logs except you, if you have access
                to the <tt>error.log</tt> file.
                <br/><br/>

                If you do not know what that all means, please do not care
                further, but then make sure that <i>none</i> of the
                entries below is checked.
                <br/><br/>

                Logging is very time and storage space consuming for
                each request and should be activated only for special tasks,
                that are usually performed by coWiki testers and programmers.
                You will obtain more information about in this in the
                <tt>core.conf-dist</tt> file or in the coWiki developer
                documentation.';

        $sStr .=  '<br/><br/>';

        $sStr .=  '<table align="center" cellspacing="0"
                    cellpadding="0" border="0">';
        $sStr .=    '<tr>';

        $sStr .=      '<td>';
        $sStr .=        '<fieldset>';
        $sStr .=          '<legend>Debug logging parameters settings</legend>';

        $sStr .=          '<table cellpadding="2" cellspacing="0"';
        $sStr .=          ' border="0" class="fieldset-content">';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<input name="D_ERR" type="checkbox"';

        if (($nLevel & Logger::D_ERR) != 0) { $sStr .= ' checked="true"'; }

        $sStr .=                ' id="D_ERR">';
        $sStr .=              '</td>';
        $sStr .=              '<td nowrap>';
        $sStr .=                '<label for="D_ERR">';
        $sStr .=                  'Log errors (D_ERR)';
        $sStr .=                '</label>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<input name="D_WARN" type="checkbox"';

        if (($nLevel & Logger::D_WARN) != 0) { $sStr .= ' checked="true"'; }

        $sStr .=                ' id="D_WARN">';
        $sStr .=              '</td>';
        $sStr .=              '<td nowrap>';
        $sStr .=                '<label for="D_WARN">';
        $sStr .=                  'Log warnings (D_WARN)';
        $sStr .=                '</label>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<input name="D_INFO" type="checkbox"';

        if (($nLevel & Logger::D_INFO) != 0) { $sStr .= ' checked="true"'; }

        $sStr .=                ' id="D_INFO">';
        $sStr .=              '</td>';
        $sStr .=              '<td nowrap>';
        $sStr .=                '<label for="D_INFO">';
        $sStr .=                  'Be generally verbose (D_INFO)';
        $sStr .=                '</label>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<input name="D_SQL" type="checkbox"';

        if (($nLevel & Logger::D_SQL) != 0) { $sStr .= ' checked="true"'; }

        $sStr .=                ' id="D_SQL">';
        $sStr .=              '</td>';
        $sStr .=              '<td nowrap>';
        $sStr .=                '<label for="D_SQL">';
        $sStr .=                  'Log SQL queries (D_SQL)';
        $sStr .=                '</label>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<input name="D_FORK" type="checkbox"';

        if (($nLevel & Logger::D_FORK) != 0) { $sStr .= ' checked="true"'; }

        $sStr .=                ' id="D_FORK">';
        $sStr .=              '</td>';
        $sStr .=              '<td nowrap>';
        $sStr .=                '<label for="D_FORK">';
        $sStr .=                  'Log if third party programs are launched
                                  (D_FORK)';
        $sStr .=                '</label>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<input name="D_IO" type="checkbox"';

        if (($nLevel & Logger::D_IO) != 0) { $sStr .= ' checked="true"'; }

        $sStr .=                ' id="D_IO">';
        $sStr .=              '</td>';
        $sStr .=              '<td nowrap>';
        $sStr .=                '<label for="D_IO">';
        $sStr .=                  'Log disk read/write access (D_IO)';
        $sStr .=                '</label>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<input name="D_EXE" type="checkbox"';

        if (($nLevel & Logger::D_EXE) != 0) { $sStr .= ' checked="true"'; }

        $sStr .=                ' id="D_EXE">';
        $sStr .=              '</td>';
        $sStr .=              '<td nowrap>';
        $sStr .=                '<label for="D_EXE">';
        $sStr .=                  'Log plugin or third party libraries
                                  invocations (D_EXE)';
        $sStr .=                '</label>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=          '</table>';
        $sStr .=        '</fieldset>';
        $sStr .=      '</td>';

        $sStr .=    '</tr>';
        $sStr .=  '</table>';

        $sStr .=  '<br/>';

        $sStr .=  '<table>';
        $sStr .=    '<tr>';
        $sStr .=      '<td class="warn">';
        $sStr .=        'TURN OFF ALL LOGGING actions in production
                        environments, except you are sure that you will
                        need them for debugging.';
        $sStr .=      '</td>';
        $sStr .=    '</tr>';
        $sStr .=  '</table>';

        // Define content
        $this->Tpl->assign('CONTENT', $sStr);

        // Define informational/warning/error messages
        $this->Tpl->assign('MESSAGE', $this->getMsgQueueFormatted());

        echo $this->Tpl->parse(SETUP_PATH.'/tpl/window.default.tpl');
    }

} // of class

?>