<?php

/**
 *
 * $Id: class.TaskDocumentStorageMySQLInformer.php,v 1.3 2005/05/08 00:58:28 dgorski Exp $
 *
 * This file is part of coWiki. coWiki is free software under the terms of
 * the GNU General Public License (GPL). Read the LICENSE file. If you did
 * not receive a copy of the license and are not able to obtain it through
 * the internet, please send a note to <license@cowiki.org> so we can mail
 * you a copy immediately.
 *
 * @package     htdocs
 * @subpackage  setup
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @copyright   (C) Daniel T. Gorski, {@link http://www.develnet.org}
 * @license     http://www.gnu.org/licenses/gpl.html
 * @version     $Revision: 1.3 $
 *
 */

/**
 * coWiki - Installer task class
 *
 * @package     htdocs
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @since       coWiki 0.4.0
 */
class TaskDocumentStorageMySQLInformer extends AbstractTask {

    private
        $Conf = null;

    // --------------------------------------------------------------------

    public function __construct($Tpl) {
        parent::__construct($Tpl);
        parent::checkValidUser();
        parent::loadClassLoader();
    }

    // --------------------------------------------------------------------

    public function isRequired() {

        // Load application configuration
        $Conf = $this->getConfig();

        // Check if the application is set up to use MySQL MyISAM tables
        // for _document_ storage
        $UriInfo = new UriInfo(
                      $Conf->getSectionKeyValue(
                        '.DOCUMENT', 'RESOURCE'
                      )
                   );

        if ($UriInfo->get('scheme') == 'mysql'
            || $UriInfo->get('scheme') == 'mysqli') {

            // Show this informer (display/render if it "is required")
            return true;
        }

        return false;
    }

    // --------------------------------------------------------------------

    public function validate() {
        return true;
    }

    // --------------------------------------------------------------------

    public function render() {

        $sStr = '<span class="warn">
                  <b>Important:</b>
                  '.COWIKI_NAME.' requires MySQL <b>InnoDB</b> storage
                  facility!
                </span>
                <br/><br/>

                As of the '.COWIKI_NAME.' 0.4.0, this software
                does not support MySQLs MyISAM tables anymore! The MyISAM
                storage facility is deprecated as it can not handle
                ACID transactions, that are required for newer versions
                of '.COWIKI_NAME.' to run.
                <br/><br/>

                <b>If you want to use MySQL as storage container for your
                documents, please make sure that your MySQL server 
                provides the InnoDB storage layer instead.</b>
                <br/><br/>

                Warning: If the MySQL server (MySQL database) isn\'t capable
                of <b>InnoDB</b>, your documents won\'t be saved properly:
                you\'ll get errors and/or your data will vanish!
                ';

        $sStr .=  '<br/><br/>';

        // Define content
        $this->Tpl->assign('CONTENT', $sStr);

        // Define informational/warning/error messages
        $this->Tpl->assign('MESSAGE', $this->getMsgQueueFormatted());

        echo $this->Tpl->parse(SETUP_PATH.'/tpl/window.default.tpl');
    }

} // of class

?>