<?php

/**
 *
 * $Id: class.TaskFilePermissionChecker.php,v 1.3 2005/05/16 22:17:54 dgorski Exp $
 *
 * This file is part of coWiki. coWiki is free software under the terms of
 * the GNU General Public License (GPL). Read the LICENSE file. If you did
 * not receive a copy of the license and are not able to obtain it through
 * the internet, please send a note to <license@cowiki.org> so we can mail
 * you a copy immediately.
 *
 * @package     htdocs
 * @subpackage  setup
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @copyright   (C) Daniel T. Gorski, {@link http://www.develnet.org}
 * @license     http://www.gnu.org/licenses/gpl.html
 * @version     $Revision: 1.3 $
 *
 */

/**
 * coWiki - Installer task class
 *
 * @package     htdocs
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @since       coWiki 0.4.0
 */
class TaskFilePermissionChecker extends AbstractTask {

    public function __construct($Tpl) {
        parent::__construct($Tpl);
        parent::checkValidUser();
    }

    // --------------------------------------------------------------------

    public function isRequired() {
        return sizeof($this->getNotAccessibleFiles()) != 0;
    }

    // --------------------------------------------------------------------

    public function validate() {
        if (sizeof($this->getNotAccessibleFiles()) != 0) {
            return $this->addError(
                'Please adjust all directory and file permissions first.
                You will need to change them manually. The wizard can not
                change them for you.'
            );
        }

        return true;
    }

    // --------------------------------------------------------------------

    public function render() {

        // Get not accessible files or directories
        $aArr = $this->getNotAccessibleFiles();

        $sStr =   '<table width="100%" cellpadding="0" cellspacing="0"';
        $sStr .=    ' border="0">';
        $sStr .=    '<tr>';
        $sStr .=      '<td>';
        $sStr .=        'Following files or directories are not accessible
                        for reading or writing for this software.
                        Modify the access permissions of these files or
                        directories accordingly. Depending on your setup,
                        the modification of access permissions of
                        directories first will help you fast.';
        $sStr .=      '</td>';
        $sStr .=    '</tr>';

        $sStr .=    '<tr>';
        $sStr .=      '<td>';
        $sStr .=        '<img src="img/0.gif" width="1" height="8" alt=""';
        $sStr .=        ' border="0">';
        $sStr .=      '</td>';
        $sStr .=    '</tr>';

        $sStr .=    '<tr>';
        $sStr .=      '<td>';
        $sStr .=        '<div class="default-scrollarea">';

        $sStr .=          '<ul style="margin-top:0px; padding-top:10px">';

        foreach ($aArr as $k => $v) {
            $sStr .=        '<li>';
            $sStr .=          $v . '<br/>';
            $sStr .=        '</li>';
        }

        $sStr .=          '</ul>';

        $sStr .=        '</div>';
        $sStr .=      '</td>';
        $sStr .=    '</tr>';

        $sStr .=  '</table>';

        // Define content
        $this->Tpl->assign('CONTENT', $sStr);

        // Define informational/warning/error messages
        $this->Tpl->assign('MESSAGE', $this->getMsgQueueFormatted());

        echo $this->Tpl->parse(SETUP_PATH.'/tpl/window.default.tpl');
    }

    // --------------------------------------------------------------------

    private function getNotAccessibleFiles() {
        $aArr = array();

        $sHtDocs = $this->State->getHtdocsPath();
        $sIncludes = $this->State->getIncludesPath();

        // ---

        if (!$this->canReadWrite($sHtDocs)) {
            $aArr[] = $sHtDocs;
        }

        if (!$this->canReadWrite($sHtDocs . '/include.path')) {
            $aArr[] = $sHtDocs . '/include.path';
        }

        if ($this->State->isUpdateSetup()) {
            if (!$this->canReadWrite($sHtDocs . '/install.seal')) {
                $aArr[] = $sHtDocs . '/install.seal';
            }
        }

/* Can't check this, as this not available in an initial setup and _may_
   be not available during an update. This check should be removed. Rethink.

        if (!$this->canReadWrite($sHtDocs . '/recent.rdf')) {
            $aArr[] = $sHtDocs . '/recent.rdf';
        }
*/
        // ---

        if (!$this->canReadWrite($sIncludes)) {
            $aArr[] = $sIncludes;
        }

        if ($this->State->isUpdateSetup()) {
            if (!$this->canReadWrite($sIncludes . '/core.conf')) {
                $aArr[] = $sIncludes . '/core.conf';
            }
        }

        if (!$this->canRead($sIncludes . '/core.conf-dist')) {
            $aArr[] = $sIncludes . '/core.conf-dist';
        }

        return $aArr;
    }

    // --------------------------------------------------------------------

    private function canReadWrite($sFile) {
        if (file_exists($sFile)) {
            return @is_readable($sFile) && @is_writable($sFile);
        }
        return false;
    }

    // --------------------------------------------------------------------

    private function canRead($sFile) {
        if (file_exists($sFile)) {
            return @is_readable($sFile);
        }
        return false;
    }

} // of class

/*
    So many little things followed me.
    So many little things that bothered me. But I found my answer.
    From all the chaos that followed me I have found my answer.
    I've told you before don't follow me, because I am not your answer.

    I am not alone, I am not afraid, I am not unhappy.
    These are the words I say to myself everyday.
    I am not alone, I am not afraid, I am not unhappy.
    Tell me what ritual I should have today.
    But I'm not alone. I've resolved so many things and set myself free.

    I am not alone, I am not afraid, I am not unhappy.
    The words I say to myself every day.
    I am not alone, I am not afraid, I am not unhappy.
    Such a stupid ritual to have to say to myself everyday.
    I'm not alone but I found my answer and set myself free. I'm not unhappy.

    I'm not alone and I'm not unhappy.
    Not alone and I'm not unhappy.
    I'm not afraid and I'm not unhappy.
*/

?>