<?php

/**
 *
 * $Id: class.TaskPathIncludeChecker.php,v 1.1 2005/04/21 00:17:14 dgorski Exp $
 *
 * This file is part of coWiki. coWiki is free software under the terms of
 * the GNU General Public License (GPL). Read the LICENSE file. If you did
 * not receive a copy of the license and are not able to obtain it through
 * the internet, please send a note to <license@cowiki.org> so we can mail
 * you a copy immediately.
 *
 * @package     htdocs
 * @subpackage  setup
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @copyright   (C) Daniel T. Gorski, {@link http://www.develnet.org}
 * @license     http://www.gnu.org/licenses/gpl.html
 * @version     $Revision: 1.1 $
 *
 */

/**
 * coWiki - Installer task class
 *
 * @package     htdocs
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @since       coWiki 0.4.0
 */
class TaskPathIncludeChecker extends AbstractTask {

    public function __construct($Tpl) {
        parent::__construct($Tpl);
        parent::checkValidUser();
    }

    // --------------------------------------------------------------------

    public function isRequired() {

        $bHtDocs   = $this->hasValidHtdocsDirectory();
        $bIncludes = $this->hasValidIncludeDirectory();
        $bMisc     = $this->hasValidMiscDirectory();
        $bClassLoader = $this->hasValidClassLoader();

        return !$bHtDocs || !$bIncludes || !$bMisc || !$bClassLoader;
    }

    // --------------------------------------------------------------------

    public function validate() {

        $this->State->setHtdocsPath(@$_POST['htdocs']);
        $this->State->setIncludesPath(@$_POST['includes']);
        $this->State->setMiscPath(@$_POST['misc']);
        $this->State->hasCompleteClassLoaderPath($this->hasValidClassLoader());

        if (!$this->hasValidHtdocsDirectory()) {
            $this->addError(
                'The <tt>htdocs/</tt> path does not point to a
                valid directory or access permission are wrong.'
            );
        }

        if (!$this->hasValidIncludeDirectory()) {
            $this->addError(
                'The <tt>includes/</tt> path does not point to a
                valid directory or access permission are wrong.'
            );
        }

        if (!$this->hasValidClassLoader()) {
            $this->addError(
                'A <tt>ClassLoader</tt> could not be found in the given
                <tt>includes/</tt> directory. Either it is not there
                or it is not readable.'
            );
        }

        if (!$this->hasValidMiscDirectory()) {
            $this->addError(
                'The <tt>misc/</tt> path does not point to a
                valid directory or access permission are wrong.'
            );
        }

        // Validation failed?
        return !$this->hasError();
    }

    // --------------------------------------------------------------------

    public function render() {

        // Disable/enable the formular input fields
        $sHtDocs   =  $this->State->getHtdocsPath() . DIRECTORY_SEPARATOR;
        $bHtDocs   =  true;

        $sIncludes =  $this->State->getIncludesPath() . DIRECTORY_SEPARATOR;
        $bIncludes =  true;

        $sMisc =  $this->State->getMiscPath() . DIRECTORY_SEPARATOR;
        $bMisc =  true;

        $sStr = '
            Basically this software needs access to three directories that
            need to be configured properly. These are the main
            directory <tt>htdocs/</tt>, the <tt>includes/</tt> and
            the <tt>misc/</tt> directory.

            <ul>
              <li>
                The <tt>htdocs/</tt> directory is the "DocumentRoot"
                directory (or below) that has been defined in your
                webserver configuration.
              </li>
              <li>
                The <tt>includes/</tt> directory contains the
                <tt>ClassLoader</tt>, business classes and configuration
                settings that <i>must not</i> be accessible by a user
                agent (browser). <tt>includes/</tt> is usually located
                somewhere <i>above</i> the "DocumentRoot" in your directory
                hierarchy.
              </li>
              <li>
                The <tt>misc/</tt> directory contains database schemas
                scripts and other files that are required. Likewise the
                <tt>includes/</tt> directory, <tt>misc/</tt> is usually
                located somewhere <i>above</i> the "DocumentRoot" in your
                directory hierarchy.
              </li>
            </ul>

            <br/>
        ';

        $sStr .=  '<table cellspacing="0" cellpadding="0" border="0">';
        $sStr .=    '<tr>';

        $sStr .=      '<td>';
        $sStr .=        '<fieldset>';
        $sStr .=          '<legend>Application include path settings</legend>';

        $sStr .=          '<table cellpadding="2" cellspacing="0"';
        $sStr .=          ' border="0" class="fieldset-content">';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<tt>htdocs/</tt> path:';
        $sStr .=              '</td>';
        $sStr .=              '<td>';
        $sStr .=                '<input type="text" name="htdocs"';
        $sStr .=                ' size="40"';
        $sStr .=                ' value="'.$sHtDocs.'"';

        if (!$bHtDocs) {  $sStr .=  ' disabled="true"'; }

        $sStr .=                '>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<tt>includes/</tt> path:';
        $sStr .=              '</td>';
        $sStr .=              '<td>';
        $sStr .=                '<input type="text" name="includes"';
        $sStr .=                ' size="40"';
        $sStr .=                ' value="'.$sIncludes.'"';

        if (!$bIncludes) {  $sStr .=  ' disabled="true"'; }

        $sStr .=                '>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=            '<tr>';
        $sStr .=              '<td nowrap align="right">';
        $sStr .=                '<tt>misc/</tt> path:';
        $sStr .=              '</td>';
        $sStr .=              '<td>';
        $sStr .=                '<input type="text" name="misc"';
        $sStr .=                ' size="40"';
        $sStr .=                ' value="'.$sMisc.'"';

        if (!$bMisc) {  $sStr .=  ' disabled="true"'; }

        $sStr .=                '>';
        $sStr .=              '</td>';
        $sStr .=            '</tr>';

        $sStr .=          '</table>';
        $sStr .=        '</fieldset>';
        $sStr .=      '</td>';

        $sStr .=    '</tr>';
        $sStr .=  '</table>';

        $sStr .=  '<br/>';

        // Define content
        $this->Tpl->assign('CONTENT', $sStr);

        // Define informational/warning/error messages
        $this->Tpl->assign('MESSAGE', $this->getMsgQueueFormatted());

        echo $this->Tpl->parse(SETUP_PATH.'/tpl/window.default.tpl');
    }

} // of class

/*
    She came from Planet Claire
    I knew she came from there

    She drove a Plymouth Satellite
    Faster than the speed of light

    Planet Claire has pink air
    All the trees are red

    No one ever dies there
    No one has a head

    Some say she's from Mars
    Or one of the seven stars
    That shine after 3:30 in the morning

    Well she isn't

    She came from Planet Claire
*/

?>