<?php

/**
 *
 * $Id: class.Migrator_20050803_01.php,v 1.1 2005/08/03 09:15:17 dgorski Exp $
 *
 * This file is part of coWiki. coWiki is free software under the terms of
 * the GNU General Public License (GPL). Read the LICENSE file. If you did
 * not receive a copy of the license and are not able to obtain it through
 * the internet, please send a note to <license@cowiki.org> so we can mail
 * you a copy immediately.
 *
 * @package     htdocs
 * @subpackage  setup
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @copyright   (C) Daniel T. Gorski, {@link http://www.develnet.org}
 * @license     http://www.gnu.org/licenses/gpl.html
 * @version     $Revision: 1.1 $
 *
 */

/**
 * Migrator implementation
 *
 * @package     htdocs
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @since       coWiki 0.4.0
 */
class Migrator_20050803_01 implements MigratorInterface {

    private
        $State = null;

    // --------------------------------------------------------------------

    public function __construct($StateHolder) {
        $this->State = $StateHolder;
    }

    // --------------------------------------------------------------------

    /**
     *  Get a short description of what this Migrator is going to do
     */
    public function getDescription() {
        return 'Extend user name space up to 16 characters.';
    }

    // --------------------------------------------------------------------

    /**
     *  Check if this Migrator has to be performed, its task is:
     *
     *  Extend user login name space in the databae up to 16 characters.
     *  Redeclare the field defintion.
     */
    public function isRequired() {

        // Get the resource DSN (database connection details)
        $UriInfo = new UriInfo($this->State->getDocumentStorageDSN());

        // Do we use MySQL? Check if this Migrator can/should generally
        // handle the requested connector scheme. If not, this Migrator is
        // "not required".
        switch ($UriInfo->get('scheme')) {

            case 'mysql':
            case 'mysqli':
            case 'mysql+innodb':
            case 'mysqli+innodb':
                break;

            default:
                // Not a known MySQL scheme, Migrator not required
                return false;
        }

        // Check if we have a valid storage connection with a valid
        // connector user and a valid database schema. If we do not, the
        // "basic" Migrators, those that create the connector user and
        // install the database schema were not executed yet. In this case
        // we assume that they will be executed first and report that this
        // very Migrator is required, although it was not able to check
        // its status (yet).
        if (!$this->State->hasValidDocStorageConnection()) {
            return true;
        }

        // ----------------------------------------------------------------

        // Check if re-definition of the login field is required.
        $Storage = StorageFactory::getInstance()->create($UriInfo);        
        $Storage->useDatabase($UriInfo->get('basepath'));

        // Get file definition of field 'login'.
        $rResult = $Storage->query(
            "SHOW COLUMNS FROM cowiki_user LIKE 'login'"
        );

        $aData = $Storage->fetchArrayAndFreeResult($rResult);

        // Check for type. Bail out if type data not available.
        if (!isset($aData['Type'])) {
            return false;
        }

        // Leave if field 'login' is already 'varchar(16)'
        if (preg_match('#\(\s*16\s*\)#', $aData['Type'])) {
            return false;
        }

        return true;
    }

    // --------------------------------------------------------------------

    /**
     *  Perform the Migrator task
     */
    public function perform() {

        // Get the connector user resource DSN (database connection details)
        $UriInfo = new UriInfo($this->State->getDocumentStorageDSN());

        // Connect to the storage/select database
        $Storage = StorageFactory::getInstance()->create($UriInfo);        
        $Storage->useDatabase($UriInfo->get('basepath'));

        // Apply changes
        $sQuery = " ALTER TABLE   cowiki_user
                          CHANGE  login login VARCHAR(16) NOT NULL";
        
        $Storage->begin();
        $Storage->query($sQuery);
        $Storage->commit();
    }

} // of class

?>