<?php

/**
 *
 * $Id: class.ClassLoader.php,v 1.3 2005/03/20 00:56:01 dgorski Exp $
 *
 * This file is part of coWiki. coWiki is free software under the terms of
 * the GNU General Public License (GPL). Read the LICENSE file. If you did
 * not receive a copy of the license and are not able to obtain it through
 * the internet, please send a note to <license@cowiki.org> so we can mail
 * you a copy immediately.
 *
 * @package     core
 * @subpackage  class
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @copyright   (C) Daniel T. Gorski, {@link http://www.develnet.org}
 * @license     http://www.gnu.org/licenses/gpl.html
 * @version     $Revision: 1.3 $
 *
 */

/**
 * coWiki - Class loader
 *
 * @package     core
 * @subpackage  class
 * @access      public
 *
 * @author      Daniel T. Gorski, <daniel.gorski@develnet.org>
 * @since       coWiki 0.4.0
 *
 * @todo        [D11N]  Complete documentation
 */
class ClassLoader {

    private
        $aCls = array();

    // --------------------------------------------------------------------

    static public function getInstance() {
        static $Inst = null;
        if (!$Inst) { $sClassName = __CLASS__; $Inst = new $sClassName; }
        return $Inst;
    }

    // --------------------------------------------------------------------

    private function ClassLoader() {
        if (!$this->aCls) {
            $this->addImportPath(dirname(__FILE__));
        }
    }

    // --------------------------------------------------------------------

    public function load($sClass) {
        $sStr = strtolower($sClass);

        if (!isset($this->aCls[$sStr])) {

            // {{{ DEBUG }}}
            if (class_exists('Logger')) {
                Logger::error('class "'.$sClass.'" not found');
            }

            throw new ClassNotFoundException($sClass.' not found');
        }

        // {{{ DEBUG }}}
        if (class_exists('Logger')) {
            Logger::io('loading "'.$sClass.'"');
        }

        if (!@include_once $this->aCls[$sStr]['path']) {
            throw new ClassNotFoundException($sClass.' not found');
        }
    }

    // --------------------------------------------------------------------

    public function getClassName($sStr) {
        if (isset($this->aCls[strtolower($sStr)]['name'])) {
            return $this->aCls[strtolower($sStr)]['name'];
        }

        return 'n/a';
    }

    // --------------------------------------------------------------------

    public function getAllClassInfo() {
        return $this->aCls;
    }

    // --------------------------------------------------------------------

    public function addImportPath($sDir) {
        if (substr($sDir, -1) != '/') {
            $sDir .= '/';
        }

        if (!is_dir($sDir)) {
            echo 'Classpath error'; // FIX
        }

        $this->_getClassData($sDir);
    }

    // --------------------------------------------------------------------

    private function _getClassData($sDir) {
        $rDir = @opendir($sDir);

        while ($sFile = @readdir($rDir)) {
            switch ($sFile) {
                case '.':
                case '..':
                case 'CVS':
                continue 2;
            }

            if (is_dir($sDir.$sFile)) {
                $this->_getClassData($sDir.$sFile.'/');
            } else {

                if (substr($sFile, 0, 5) == 'class'
                    || substr($sFile,0, 9) == 'interface') {

                    $aParts = explode('.', $sFile);

                    if(strtolower(end($aParts)) == 'php') {
                        $this->aCls[strtolower($aParts[1])]['name']
                            = $aParts[1];
                        $this->aCls[strtolower($aParts[1])]['path']
                            = $sDir . $sFile;
                    }
                }
            }
        }

        @closedir($rDir);
    }

} // of class

/*
    Come closer and see
    See into the trees
    Find the girl
    While you can
    Come closer and see
    See into the dark
    Just follow your eyes

    I hear her voice
    Calling my name
    The sound is deep
    In the dark
    I hear her voice
    And start to run
    Into the trees

    Suddenly I stop
    But I know it's too late
    I'm lost in a forest
    All alone
    The girl was never there
    It's always the same
    I'm running towards nothing
    Again and again and again
*/

?>