<?php

/**
 *
 * $Id: class.WikiPseudoXmlConverter.php,v 1.1 2006/03/20 15:53:57 cmarble Exp $
 *
 * This file is part of coWiki. coWiki is free software under the terms of
 * the GNU General Public License (GPL). Read the LICENSE file. If you did
 * not receive a copy of the license and are not able to obtain it through
 * the internet, please send a note to <license@cowiki.org> so we can mail
 * you a copy immediately.
 *
 * @package     parse
 * @subpackage  class
 * @access      public
 *
 * @author      Archie Campbell <cephalicmarble@blueyonder.co.uk>
 * @since       coWiki 0.4.0
 * @copyright   (C) Archie Campbell
 * @license     http://www.gnu.org/licenses/gpl.html
 * @version     $Revision: 1.1 $
 *
 */

/**
 * coWiki - old-style Wiki XML to strict XML converter.
 *
 * @package     parse
 * @subpackage  class
 * @access      public
 *
 * @author      Archie Campbell <cephalicmarble@blueyonder.co.uk>
 * @since       coWiki 0.4.0
 *
 */

class WikiPseudoXmlConverter extends Object {

    protected static
        $Instance = null;

    protected $aRow = array(),
              $sContent = '';

    // --------------------------------------------------------------------

    /**
     * Get instance
     *
     * @access  public
     *
     * @author      Archie Campbell <cephalicmarble@blueyonder.co.uk>
     * @since       coWiki 0.4.0
     */
    public function getInstance() {
        if (!self::$Instance) {
            self::$Instance = new WikiPseudoXmlConverter;
        }
        return self::$Instance;
    }

    // --- Helper methods -------------------------------------------------

    /**
     * Helper functions
     *
     * @author  Archie Campbell <cephalicmarble@blueyonder.co.uk>
     * @since   coWiki 0.4.0
     *
     */
    protected function appendRow($sStr){
        array_push($this->aRow,$sStr);
        $this->clearContent();
    }
    protected function clearContent(){
        $this->sContent = '';
    }
    protected function clearRow() {
        if(trim($this->sContent)!=''){
            $this->appendRow($this->sContent);
        }
    }

    /**
     * @access  protected
     *
     * @author      Archie Campbell <cephalicmarble@blueyonder.co.uk>
     * @since       coWiki 0.4.0
     */
    public function parse( $sStr ) {

        $debug = false;
        $aRow = array();
        $sContent = '';

        $sRet = '';

        if(preg_match("#^<document>#",$sStr)) {
          if($debug){echo "Already got <document>\n";}
            return $sStr;
        }

        // Replace web/document delimiter
        $sStr = str_replace('', '|', $sStr);

        // Replace possible tabulators
        $sStr = str_replace("\t", '    ', $sStr);

        // Replace possible \r\n or \n\r with \n
        $sStr = str_replace("\r\n", "\n", $sStr);
        $sStr = str_replace("\n\r", "\n", $sStr);

        // Prepare XML, add root element
        $sStr = '<document>' . $sStr . '</document>';

        /*
        xml_set_default_handler( $this->rParser, 
                                array(&$this,'xml_default_handler') );
        xml_set_element_handler( $this->rParser,
                                array(&$this,'xml_start_handler'),
                                array(&$this,'xml_end_handler') );
        xml_set_character_data_handler( $this->rParser,
                                array(&$this,'xml_cdata_handler') );
        */

        $aLines = explode( "\n",$sStr);
        $max = sizeof($aLines);
        $lc = 0;

        while($lc < $max){ 
            $sLine = $aLines[$lc]."\n";
            if($debug) {echo "parsing ".$sLine."\n";}
            while($sLine!='') {
                if( preg_match( '#^<(/?)([a-z0-9]*)((\s[a-z0-9]*=\"[^\"]*\")*)(/?)>#i',
                            $sLine, $aMatches ) ) {
                  if($debug){echo "aMatches ='".implode(",",$aMatches)."'\n";}
                    if($this->sContent!=''){
                        $sRet .= "<![CDATA[".$this->sContent."]]>";
                        $this->clearContent();
                    }
                    if($aMatches[1]=='/') {
                        $sRet .= "</";
                    }else{
                        $sRet .= "<";
                    }
                    $sRet .= $aMatches[2];
                    if ($aMatches[3]!='') {
                        $sRet .= ">";
                        $attrib = $aMatches[3];
                        while($attrib!=''){
                            if( preg_match('#^([a-z0-9]*)=\"([^\"]*)\"#',
                                           $attrib,$aMatch ) ) {
                                  $sRet .=  "<".$aMatch[1]."><![CDATA[".
                                  $aMatch[2]."]]>"."</".$aMatch[1].">";
                                $attrib = substr($attrib,strlen($aMatch[0]));
                            }else{
                                $attrib = substr($attrib,1);
                            }
                        }
                    }else{
                        if($aMatches[5]=='/'){
                            $sRet .= "/>";
                        }else{
                            $sRet .= ">";
                        }
                    }
                    if($aMatches[2]=='plugin') {
                        $sRet .= "</plugin>";
                    }
                    $sLine = substr($sLine,strlen($aMatches[0]));
                }else{
                    $this->sContent .= $sLine{0};
                    $sLine = substr($sLine,1);
                }
            }
            $lc++;
        }
        return $sRet;
    }
}
?>